@@ -3,21 +3,20 @@
 //!
 
 use dataplane::api::Request;
-use dataplane::derive::Decode;
-use dataplane::derive::Encode;
+use dataplane::core::{Encoder, Decoder};
 use dataplane::Offset;
 
 use crate::errors::ErrorCode;
 use super::SpuServerApiKey;
 
-#[derive(Decode, Encode, Default, Debug)]
+#[derive(Decoder, Encoder, Default, Debug)]
 pub struct OffsetUpdate {
     pub offset: Offset,
     pub session_id: u32,
 }
 
 /// send out current offset to SPU
-#[derive(Decode, Encode, Default, Debug)]
+#[derive(Decoder, Encoder, Default, Debug)]
 pub struct UpdateOffsetsRequest {
     pub offsets: Vec<OffsetUpdate>,
 }
@@ -34,13 +33,13 @@ impl UpdateOffsetsRequest {
     }
 }
 
-#[derive(Decode, Encode, Default, Debug)]
+#[derive(Decoder, Encoder, Default, Debug)]
 pub struct OffsetUpdateStatus {
     pub session_id: u32,
     pub error: ErrorCode,
 }
 
-#[derive(Encode, Decode, Default, Debug)]
+#[derive(Encoder, Decoder, Default, Debug)]
 pub struct UpdateOffsetsResponse {
     pub status: Vec<OffsetUpdateStatus>,
 }
